@@ -7,4 +7,4 @@ mod metadata;
 mod recipe_entry;
 
 pub use metadata::Metadata;
-pub use recipe_entry::{RecipeEntry, RecipeEntryError};
+pub use recipe_entry::{RecipeEntry, RecipeEntryError, StepImageCollection};
